"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.build_settings.build_settings_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SaveBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def build_settings(self) -> qwak.build_settings.build_settings_pb2.BuildSettings: ...
    @property
    def environment_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_settings: qwak.build_settings.build_settings_pb2.BuildSettings | None = ...,
        environment_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings", "environment_id", b"environment_id"]) -> None: ...

global___SaveBuildSettingsRequest = SaveBuildSettingsRequest

class SaveBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_ID_FIELD_NUMBER: builtins.int
    @property
    def build_settings_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        build_settings_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings_id", b"build_settings_id"]) -> None: ...

global___SaveBuildSettingsResponse = SaveBuildSettingsResponse

class GetBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetBuildSettingsRequest = GetBuildSettingsRequest

class GetBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def build_settings(self) -> qwak.build_settings.build_settings_pb2.BuildSettings: ...
    def __init__(
        self,
        *,
        build_settings: qwak.build_settings.build_settings_pb2.BuildSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_settings", b"build_settings"]) -> None: ...

global___GetBuildSettingsResponse = GetBuildSettingsResponse

class DeleteBuildSettingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___DeleteBuildSettingsRequest = DeleteBuildSettingsRequest

class DeleteBuildSettingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteBuildSettingsResponse = DeleteBuildSettingsResponse
