"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UserDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User id"""
    display_name: builtins.str
    """User display name"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id"]) -> None: ...

global___UserDetails = UserDetails

class EnvironmentDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Environment id"""
    @property
    def configuration(self) -> global___EnvironmentConfiguration:
        """Environment configuration"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        configuration: global___EnvironmentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "id", b"id"]) -> None: ...

global___EnvironmentDetails = EnvironmentDetails

class EnvironmentConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EDGE_SERVICES_URL_FIELD_NUMBER: builtins.int
    MANAGEMENT_ACCESS_URL_FIELD_NUMBER: builtins.int
    MODEL_API_URL_FIELD_NUMBER: builtins.int
    ANALYTICS_DATA_API_URL_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_BUCKET_FIELD_NUMBER: builtins.int
    BI_SYSTEM_API_KEY_FIELD_NUMBER: builtins.int
    CLOUD_CONFIGURATION_FIELD_NUMBER: builtins.int
    edge_services_url: builtins.str
    """The Grpc service url on edge"""
    management_access_url: builtins.str
    """The management url of inter qwak services communication"""
    model_api_url: builtins.str
    """The endpoint of the models of actions like inference"""
    analytics_data_api_url: builtins.str
    """The endpoint which the analytics data is send to"""
    object_storage_bucket: builtins.str
    """The object storage bucket name of the environment"""
    bi_system_api_key: builtins.str
    """The BI system token of the environment"""
    @property
    def cloud_configuration(self) -> global___QwakCloudConfiguration:
        """Configuration specific for the environment hosting cloud"""
    def __init__(
        self,
        *,
        edge_services_url: builtins.str = ...,
        management_access_url: builtins.str = ...,
        model_api_url: builtins.str = ...,
        analytics_data_api_url: builtins.str = ...,
        object_storage_bucket: builtins.str = ...,
        bi_system_api_key: builtins.str = ...,
        cloud_configuration: global___QwakCloudConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_configuration", b"cloud_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytics_data_api_url", b"analytics_data_api_url", "bi_system_api_key", b"bi_system_api_key", "cloud_configuration", b"cloud_configuration", "edge_services_url", b"edge_services_url", "management_access_url", b"management_access_url", "model_api_url", b"model_api_url", "object_storage_bucket", b"object_storage_bucket"]) -> None: ...

global___EnvironmentConfiguration = EnvironmentConfiguration

class QwakCloudConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_CLOUD_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def aws_cloud_configuration(self) -> global___AwsCloudConfiguration: ...
    def __init__(
        self,
        *,
        aws_cloud_configuration: global___AwsCloudConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_cloud_configuration", b"aws_cloud_configuration", "configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_cloud_configuration", b"aws_cloud_configuration", "configuration", b"configuration"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["configuration", b"configuration"]) -> typing_extensions.Literal["aws_cloud_configuration"] | None: ...

global___QwakCloudConfiguration = QwakCloudConfiguration

class AwsCloudConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    WORKGROUP_FIELD_NUMBER: builtins.int
    region: builtins.str
    """The region of the environment"""
    role_arn: builtins.str
    """The role ARN which qwak platform perform actions on behalf"""
    external_id: builtins.str
    """The external id that is needed to assume the role_arn"""
    workgroup: builtins.str
    """The workgroup that is needed to perform actions on Athena"""
    def __init__(
        self,
        *,
        region: builtins.str = ...,
        role_arn: builtins.str = ...,
        external_id: builtins.str = ...,
        workgroup: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_id", b"external_id", "region", b"region", "role_arn", b"role_arn", "workgroup", b"workgroup"]) -> None: ...

global___AwsCloudConfiguration = AwsCloudConfiguration
