"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.sources.data_source_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source specifications to create"""
    def __init__(
        self,
        *,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> None: ...

global___CreateDataSourceRequest = CreateDataSourceRequest

class CreateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """The newly created data source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___CreateDataSourceResponse = CreateDataSourceResponse

class UpdateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """Data source ID to update"""
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source specifications to update"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id", "data_source_spec", b"data_source_spec"]) -> None: ...

global___UpdateDataSourceRequest = UpdateDataSourceRequest

class UpdateDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """The updated data source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___UpdateDataSourceResponse = UpdateDataSourceResponse

class DeleteDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """ID of the data source to delete"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id"]) -> None: ...

global___DeleteDataSourceRequest = DeleteDataSourceRequest

class DeleteDataSourceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteDataSourceResponse = DeleteDataSourceResponse

class GetDataSourceByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    data_source_id: builtins.str
    """ID of the data source to fetch"""
    def __init__(
        self,
        *,
        data_source_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_id", b"data_source_id"]) -> None: ...

global___GetDataSourceByIdRequest = GetDataSourceByIdRequest

class GetDataSourceByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """Fetched Data Source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___GetDataSourceByIdResponse = GetDataSourceByIdResponse

class GetDataSourceByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    data_source_name: builtins.str
    """Name of the data source to fetch"""
    def __init__(
        self,
        *,
        data_source_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_name", b"data_source_name"]) -> None: ...

global___GetDataSourceByNameRequest = GetDataSourceByNameRequest

class GetDataSourceByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def data_source(self) -> qwak.feature_store.sources.data_source_pb2.DataSource:
        """Fetched Data Source"""
    def __init__(
        self,
        *,
        data_source: qwak.feature_store.sources.data_source_pb2.DataSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

global___GetDataSourceByNameResponse = GetDataSourceByNameResponse

class ListDataSourcesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListDataSourcesRequest = ListDataSourcesRequest

class ListDataSourcesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCES_FIELD_NUMBER: builtins.int
    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.sources.data_source_pb2.DataSource]:
        """All the data sources belonging to the callers' partner id / user id"""
    def __init__(
        self,
        *,
        data_sources: collections.abc.Iterable[qwak.feature_store.sources.data_source_pb2.DataSource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_sources", b"data_sources"]) -> None: ...

global___ListDataSourcesResponse = ListDataSourcesResponse

class CreateDataSourceUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_NAME_FIELD_NUMBER: builtins.int
    OBJECT_NAME_FIELD_NUMBER: builtins.int
    data_source_name: builtins.str
    """Data source name"""
    object_name: builtins.str
    """Object name"""
    def __init__(
        self,
        *,
        data_source_name: builtins.str = ...,
        object_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_name", b"data_source_name", "object_name", b"object_name"]) -> None: ...

global___CreateDataSourceUploadURLRequest = CreateDataSourceUploadURLRequest

class CreateDataSourceUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the data source configuration"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___CreateDataSourceUploadURLResponse = CreateDataSourceUploadURLResponse
