# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/elasticsearch_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import auth_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPqwak/administration/runtime_configuration/v0/external/elasticsearch_config.proto\x12Jqwak.administration.runtime_configuration.v0.external.elasticsearch_config\x1a=qwak/administration/runtime_configuration/v0/creds/auth.proto\"\x9d\x01\n\x1a\x45lasticsearchConfiguration\x12S\n\x05\x62\x61sic\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.creds.auth.BasicAuthH\x00\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x42\x0b\n\tauth_typeB\xfc\x01\nCcom.jfrog.ml.runtime_configuration.v0.external.elasticsearch_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')



_ELASTICSEARCHCONFIGURATION = DESCRIPTOR.message_types_by_name['ElasticsearchConfiguration']
ElasticsearchConfiguration = _reflection.GeneratedProtocolMessageType('ElasticsearchConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ELASTICSEARCHCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.elasticsearch_config.ElasticsearchConfiguration)
  })
_sym_db.RegisterMessage(ElasticsearchConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCcom.jfrog.ml.runtime_configuration.v0.external.elasticsearch_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _ELASTICSEARCHCONFIGURATION._serialized_start=224
  _ELASTICSEARCHCONFIGURATION._serialized_end=381
# @@protoc_insertion_point(module_scope)
