# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRqwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto\x12Lqwak.administration.runtime_configuration.v0.external.victoriametrics_config\"\x1e\n\x1cVictoriaMetricsConfigurationB\xfe\x01\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')



_VICTORIAMETRICSCONFIGURATION = DESCRIPTOR.message_types_by_name['VictoriaMetricsConfiguration']
VictoriaMetricsConfiguration = _reflection.GeneratedProtocolMessageType('VictoriaMetricsConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _VICTORIAMETRICSCONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.external.victoriametrics_config.VictoriaMetricsConfiguration)
  })
_sym_db.RegisterMessage(VictoriaMetricsConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _VICTORIAMETRICSCONFIGURATION._serialized_start=164
  _VICTORIAMETRICSCONFIGURATION._serialized_end=194
# @@protoc_insertion_point(module_scope)
