"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VariationMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTED_VARIATION_MAPPING_NAME_FIELD_NUMBER: builtins.int
    TRAFFIC_REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    TRAFFIC_MAPPING_SPEC_FIELD_NUMBER: builtins.int
    selected_variation_mapping_name: builtins.str
    """Variation name"""
    traffic_request_timeout_ms: builtins.int
    """Timeout of the request in ms"""
    deployment_id: builtins.str
    """Deployment id which the variation mapping apply to"""
    @property
    def traffic_mapping_spec(self) -> global___TrafficMappingSpec: ...
    def __init__(
        self,
        *,
        selected_variation_mapping_name: builtins.str = ...,
        traffic_request_timeout_ms: builtins.int = ...,
        deployment_id: builtins.str = ...,
        traffic_mapping_spec: global___TrafficMappingSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mapping_spec", b"mapping_spec", "traffic_mapping_spec", b"traffic_mapping_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "mapping_spec", b"mapping_spec", "selected_variation_mapping_name", b"selected_variation_mapping_name", "traffic_mapping_spec", b"traffic_mapping_spec", "traffic_request_timeout_ms", b"traffic_request_timeout_ms"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["mapping_spec", b"mapping_spec"]) -> typing_extensions.Literal["traffic_mapping_spec"] | None: ...

global___VariationMapping = VariationMapping

class TrafficMappingSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    IS_SHADOW_FIELD_NUMBER: builtins.int
    percentage: builtins.int
    """Percentage to deflect traffic to."""
    is_shadow: builtins.bool
    """Is shadow"""
    def __init__(
        self,
        *,
        percentage: builtins.int = ...,
        is_shadow: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_shadow", b"is_shadow", "percentage", b"percentage"]) -> None: ...

global___TrafficMappingSpec = TrafficMappingSpec
