# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.build.v1 import build_api_pb2 as qwak_dot_build_dot_v1_dot_build__api__pb2


class BuildAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.FromString,
                )
        self.UpdateBuildStatus = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/UpdateBuildStatus',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.FromString,
                )
        self.RegisterExperimentTracking = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterExperimentTracking',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.FromString,
                )
        self.RegisterTags = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterTags',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.FromString,
                )
        self.RegisterModelSchema = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RegisterModelSchema',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.FromString,
                )
        self.GetBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.FromString,
                )
        self.ListBuilds = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/ListBuilds',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.FromString,
                )
        self.DeleteBuild = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/DeleteBuild',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.FromString,
                )
        self.LogPhaseStatus = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/LogPhaseStatus',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.FromString,
                )
        self.GetPhaseStatuses = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetPhaseStatuses',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.FromString,
                )
        self.GetTagPath = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetTagPath',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.FromString,
                )
        self.RerunBuildFromExisting = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/RerunBuildFromExisting',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.FromString,
                )
        self.SaveFrameworkModels = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/SaveFrameworkModels',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.FromString,
                )
        self.GetBuildsArtifactsScanSummary = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScanSummary',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.FromString,
                )
        self.GetBuildImageDetails = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildImageDetails',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.FromString,
                )
        self.UpdateBuildName = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/UpdateBuildName',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.FromString,
                )
        self.GetBuildsArtifactsScan = channel.unary_unary(
                '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScan',
                request_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.SerializeToString,
                response_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.FromString,
                )


class BuildAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBuildStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterExperimentTracking(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterModelSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBuilds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBuild(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogPhaseStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPhaseStatuses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTagPath(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RerunBuildFromExisting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveFrameworkModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildsArtifactsScanSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildImageDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBuildName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBuildsArtifactsScan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BuildAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.SerializeToString,
            ),
            'UpdateBuildStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBuildStatus,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.SerializeToString,
            ),
            'RegisterExperimentTracking': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterExperimentTracking,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.SerializeToString,
            ),
            'RegisterTags': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterTags,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.SerializeToString,
            ),
            'RegisterModelSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterModelSchema,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.SerializeToString,
            ),
            'GetBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.SerializeToString,
            ),
            'ListBuilds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBuilds,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.SerializeToString,
            ),
            'DeleteBuild': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBuild,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.SerializeToString,
            ),
            'LogPhaseStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.LogPhaseStatus,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.SerializeToString,
            ),
            'GetPhaseStatuses': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPhaseStatuses,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.SerializeToString,
            ),
            'GetTagPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTagPath,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.SerializeToString,
            ),
            'RerunBuildFromExisting': grpc.unary_unary_rpc_method_handler(
                    servicer.RerunBuildFromExisting,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.SerializeToString,
            ),
            'SaveFrameworkModels': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveFrameworkModels,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.SerializeToString,
            ),
            'GetBuildsArtifactsScanSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildsArtifactsScanSummary,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.SerializeToString,
            ),
            'GetBuildImageDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildImageDetails,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.SerializeToString,
            ),
            'UpdateBuildName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBuildName,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.SerializeToString,
            ),
            'GetBuildsArtifactsScan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildsArtifactsScan,
                    request_deserializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.FromString,
                    response_serializer=qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.qwak.build.v1.BuildAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BuildAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBuildStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/UpdateBuildStatus',
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterExperimentTracking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterExperimentTracking',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterExperimentTrackingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterTags',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterModelSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RegisterModelSchema',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RegisterModelSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBuilds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/ListBuilds',
            qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.ListBuildsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBuild(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/DeleteBuild',
            qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.DeleteBuildResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogPhaseStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/LogPhaseStatus',
            qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.LogPhaseStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPhaseStatuses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetPhaseStatuses',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetPhaseStatusesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTagPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetTagPath',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetTagPathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RerunBuildFromExisting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/RerunBuildFromExisting',
            qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.RerunBuildFromExistingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveFrameworkModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/SaveFrameworkModels',
            qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.SaveFrameworkModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildsArtifactsScanSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScanSummary',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildImageDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildImageDetails',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildImageDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBuildName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/UpdateBuildName',
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.UpdateBuildNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBuildsArtifactsScan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/com.qwak.build.v1.BuildAPI/GetBuildsArtifactsScan',
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanRequest.SerializeToString,
            qwak_dot_build_dot_v1_dot_build__api__pb2.GetBuildsArtifactsScanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
