# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build_url.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/builds/build_url.proto\x12\x18qwak.builds.orchestrator\"\xe7\x01\n\x18\x42uildVersioningUrlParams\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x04 \x01(\t\x12\x43\n\x08tag_type\x18\x05 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\x12$\n\x1ause_cloud_provider_storage\x18\x06 \x01(\x08H\x00\x42\x17\n\x15\x63loud_provider_option\"\xb5\x01\n\x13\x42uildVersioningTags\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x10\n\x04tags\x18\x03 \x03(\tB\x02\x18\x01\x12P\n\x0ftags_definition\x18\x04 \x03(\x0b\x32\x37.qwak.builds.orchestrator.BuildVersioningTagsDefinition\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"n\n\x1d\x42uildVersioningTagsDefinition\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\"\xf8\x01\n\x1d\x42uildVersioningTagsProperties\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12\x11\n\tfile_size\x18\x03 \x01(\x03\x12\x43\n\x08tag_type\x18\x04 \x01(\x0e\x32\x31.qwak.builds.orchestrator.BuildVersioningTagsType\x12\x44\n\x15\x65xternal_download_url\x18\x05 \x01(\x0b\x32%.qwak.builds.orchestrator.ExternalUrl\x12\x16\n\x0eui_direct_link\x18\x06 \x01(\t\"5\n\x0b\x45xternalUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x19\n\x11original_hostname\x18\x02 \x01(\t\"Z\n\x15\x42uildArtifactPathSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x10\n\x08key_path\x18\x04 \x01(\t\"\x0e\n\x0c\x44\x61taArtifact\"\x0e\n\x0c\x43odeArtifact\"\x0e\n\x0c\x46ileArtifact\"\xf6\x01\n\rBuildArtifact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\rdata_artifact\x18\x02 \x01(\x0b\x32&.qwak.builds.orchestrator.DataArtifactH\x00\x12?\n\rcode_artifact\x18\x03 \x01(\x0b\x32&.qwak.builds.orchestrator.CodeArtifactH\x00\x12?\n\rfile_artifact\x18\x04 \x01(\x0b\x32&.qwak.builds.orchestrator.FileArtifactH\x00\x12\x0c\n\x04path\x18\x05 \x01(\tB\x06\n\x04type*h\n\x17\x42uildVersioningTagsType\x12\x14\n\x10INVALID_TAG_TYPE\x10\x00\x12\x11\n\rDATA_TAG_TYPE\x10\x01\x12\x11\n\rFILE_TAG_TYPE\x10\x02\x12\x11\n\rCODE_TAG_TYPE\x10\x03\x42\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_BUILDVERSIONINGTAGSTYPE = DESCRIPTOR.enum_types_by_name['BuildVersioningTagsType']
BuildVersioningTagsType = enum_type_wrapper.EnumTypeWrapper(_BUILDVERSIONINGTAGSTYPE)
INVALID_TAG_TYPE = 0
DATA_TAG_TYPE = 1
FILE_TAG_TYPE = 2
CODE_TAG_TYPE = 3


_BUILDVERSIONINGURLPARAMS = DESCRIPTOR.message_types_by_name['BuildVersioningUrlParams']
_BUILDVERSIONINGTAGS = DESCRIPTOR.message_types_by_name['BuildVersioningTags']
_BUILDVERSIONINGTAGSDEFINITION = DESCRIPTOR.message_types_by_name['BuildVersioningTagsDefinition']
_BUILDVERSIONINGTAGSPROPERTIES = DESCRIPTOR.message_types_by_name['BuildVersioningTagsProperties']
_EXTERNALURL = DESCRIPTOR.message_types_by_name['ExternalUrl']
_BUILDARTIFACTPATHSPEC = DESCRIPTOR.message_types_by_name['BuildArtifactPathSpec']
_DATAARTIFACT = DESCRIPTOR.message_types_by_name['DataArtifact']
_CODEARTIFACT = DESCRIPTOR.message_types_by_name['CodeArtifact']
_FILEARTIFACT = DESCRIPTOR.message_types_by_name['FileArtifact']
_BUILDARTIFACT = DESCRIPTOR.message_types_by_name['BuildArtifact']
BuildVersioningUrlParams = _reflection.GeneratedProtocolMessageType('BuildVersioningUrlParams', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGURLPARAMS,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningUrlParams)
  })
_sym_db.RegisterMessage(BuildVersioningUrlParams)

BuildVersioningTags = _reflection.GeneratedProtocolMessageType('BuildVersioningTags', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGS,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTags)
  })
_sym_db.RegisterMessage(BuildVersioningTags)

BuildVersioningTagsDefinition = _reflection.GeneratedProtocolMessageType('BuildVersioningTagsDefinition', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGSDEFINITION,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTagsDefinition)
  })
_sym_db.RegisterMessage(BuildVersioningTagsDefinition)

BuildVersioningTagsProperties = _reflection.GeneratedProtocolMessageType('BuildVersioningTagsProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDVERSIONINGTAGSPROPERTIES,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildVersioningTagsProperties)
  })
_sym_db.RegisterMessage(BuildVersioningTagsProperties)

ExternalUrl = _reflection.GeneratedProtocolMessageType('ExternalUrl', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALURL,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ExternalUrl)
  })
_sym_db.RegisterMessage(ExternalUrl)

BuildArtifactPathSpec = _reflection.GeneratedProtocolMessageType('BuildArtifactPathSpec', (_message.Message,), {
  'DESCRIPTOR' : _BUILDARTIFACTPATHSPEC,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildArtifactPathSpec)
  })
_sym_db.RegisterMessage(BuildArtifactPathSpec)

DataArtifact = _reflection.GeneratedProtocolMessageType('DataArtifact', (_message.Message,), {
  'DESCRIPTOR' : _DATAARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataArtifact)
  })
_sym_db.RegisterMessage(DataArtifact)

CodeArtifact = _reflection.GeneratedProtocolMessageType('CodeArtifact', (_message.Message,), {
  'DESCRIPTOR' : _CODEARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CodeArtifact)
  })
_sym_db.RegisterMessage(CodeArtifact)

FileArtifact = _reflection.GeneratedProtocolMessageType('FileArtifact', (_message.Message,), {
  'DESCRIPTOR' : _FILEARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.FileArtifact)
  })
_sym_db.RegisterMessage(FileArtifact)

BuildArtifact = _reflection.GeneratedProtocolMessageType('BuildArtifact', (_message.Message,), {
  'DESCRIPTOR' : _BUILDARTIFACT,
  '__module__' : 'qwak.builds.build_url_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildArtifact)
  })
_sym_db.RegisterMessage(BuildArtifact)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _BUILDVERSIONINGTAGS.fields_by_name['tags']._options = None
  _BUILDVERSIONINGTAGS.fields_by_name['tags']._serialized_options = b'\030\001'
  _BUILDVERSIONINGTAGSTYPE._serialized_start=1282
  _BUILDVERSIONINGTAGSTYPE._serialized_end=1386
  _BUILDVERSIONINGURLPARAMS._serialized_start=58
  _BUILDVERSIONINGURLPARAMS._serialized_end=289
  _BUILDVERSIONINGTAGS._serialized_start=292
  _BUILDVERSIONINGTAGS._serialized_end=473
  _BUILDVERSIONINGTAGSDEFINITION._serialized_start=475
  _BUILDVERSIONINGTAGSDEFINITION._serialized_end=585
  _BUILDVERSIONINGTAGSPROPERTIES._serialized_start=588
  _BUILDVERSIONINGTAGSPROPERTIES._serialized_end=836
  _EXTERNALURL._serialized_start=838
  _EXTERNALURL._serialized_end=891
  _BUILDARTIFACTPATHSPEC._serialized_start=893
  _BUILDARTIFACTPATHSPEC._serialized_end=983
  _DATAARTIFACT._serialized_start=985
  _DATAARTIFACT._serialized_end=999
  _CODEARTIFACT._serialized_start=1001
  _CODEARTIFACT._serialized_end=1015
  _FILEARTIFACT._serialized_start=1017
  _FILEARTIFACT._serialized_end=1031
  _BUILDARTIFACT._serialized_start=1034
  _BUILDARTIFACT._serialized_end=1280
# @@protoc_insertion_point(module_scope)
