"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    featureset_name: builtins.str
    """TODO - FILL THIS WITH THE ACTUAL STATE REPRESENTATION
    we need to find an elegant way of representing a state that is not just an enum value -
    for example, in streaming aggr, if compaction failed but row-level is running.
    another example is batchV1 where batch ingestion worked but realtime is failing
    """
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "featureset_name", b"featureset_name"]) -> None: ...

global___FeaturesetState = FeaturesetState
