"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.audience.v1.audience_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> None: ...

global___CreateAudienceRequest = CreateAudienceRequest

class CreateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___CreateAudienceResponse = CreateAudienceResponse

class UpdateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "id", b"id"]) -> None: ...

global___UpdateAudienceRequest = UpdateAudienceRequest

class UpdateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAudienceResponse = UpdateAudienceResponse

class GetAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___GetAudienceRequest = GetAudienceRequest

class GetAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    @property
    def audience(self) -> qwak.audience.v1.audience_pb2.Audience: ...
    def __init__(
        self,
        *,
        audience: qwak.audience.v1.audience_pb2.Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> None: ...

global___GetAudienceResponse = GetAudienceResponse

class ListAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAudienceRequest = ListAudienceRequest

class ListAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def audience_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.audience.v1.audience_pb2.AudienceEntry]: ...
    def __init__(
        self,
        *,
        audience_entries: collections.abc.Iterable[qwak.audience.v1.audience_pb2.AudienceEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_entries", b"audience_entries"]) -> None: ...

global___ListAudienceResponse = ListAudienceResponse

class DeleteAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id"]) -> None: ...

global___DeleteAudienceRequest = DeleteAudienceRequest

class DeleteAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAudienceResponse = DeleteAudienceResponse

class SyncAudiencesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___SyncAudiencesRequest = SyncAudiencesRequest

class SyncAudiencesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SyncAudiencesResponse = SyncAudiencesResponse
