"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.auto_scaling.v1.auto_scaling_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AttachAutoScalingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    AUTO_SCALING_CONFIG_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The ID of the model to scale"""
    variation_name: builtins.str
    """Deployment variation name"""
    @property
    def auto_scaling_config(self) -> qwak.auto_scaling.v1.auto_scaling_pb2.AutoScalingConfig:
        """Auto scaling"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        variation_name: builtins.str = ...,
        auto_scaling_config: qwak.auto_scaling.v1.auto_scaling_pb2.AutoScalingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_scaling_config", b"auto_scaling_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_config", b"auto_scaling_config", "model_id", b"model_id", "variation_name", b"variation_name"]) -> None: ...

global___AttachAutoScalingRequest = AttachAutoScalingRequest

class AttachAutoScalingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_SCALING_ID_FIELD_NUMBER: builtins.int
    auto_scaling_id: builtins.str
    def __init__(
        self,
        *,
        auto_scaling_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_scaling_id", b"auto_scaling_id"]) -> None: ...

global___AttachAutoScalingResponse = AttachAutoScalingResponse
