# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/batch_job/v1/batch_job_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.batch_job.v1 import batch_job_events_pb2 as qwak_dot_batch__job_dot_v1_dot_batch__job__events__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import credentials_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/batch_job/v1/batch_job_service.proto\x12\rqwak.batchjob\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a(qwak/batch_job/v1/batch_job_events.proto\x1a;qwak/administration/authenticated_user/v1/credentials.proto\"\xb4\x01\n\x15StartWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x05 \x01(\t\x12\x16\n\x0ewarmup_timeout\x18\x03 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x04 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\"B\n\x16StartWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"S\n\x16\x43\x61ncelWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"C\n\x17\x43\x61ncelWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"\x89\x05\n\x14StartBatchJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\x12\x15\n\rsource_bucket\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x04 \x01(\t\x12\x15\n\rsource_folder\x18\x05 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x06 \x01(\t\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12\x13\n\x0bjob_timeout\x18\x08 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\t \x01(\x05\x12\x35\n\x0finput_file_type\x18\n \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x0b \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x0e \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x10 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\x12\x39\n\x11\x62\x61tch_job_request\x18\x11 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobRequest\"\xcb\x01\n\x0f\x42\x61tchJobRequest\x12:\n\rmodel_details\x18\x01 \x01(\x0b\x32#.qwak.batchjob.BatchJobModelDetails\x12\x38\n\x0c\x64\x61ta_details\x18\x02 \x01(\x0b\x32\".qwak.batchjob.BatchJobDataDetails\x12\x42\n\x11\x65xecution_details\x18\x04 \x01(\x0b\x32\'.qwak.batchjob.BatchJobExecutionDetails\":\n\x14\x42\x61tchJobModelDetails\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\"\xe5\x01\n\x13\x42\x61tchJobDataDetails\x12\x36\n\x0bsource_path\x18\x01 \x01(\x0b\x32!.qwak.batchjob.BatchJobSourcePath\x12@\n\x10\x64\x65stination_path\x18\x02 \x01(\x0b\x32&.qwak.batchjob.BatchJobDestinationPath\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12\'\n\x1fservice_account_json_key_secret\x18\x05 \x01(\t\"y\n\x12\x42\x61tchJobSourcePath\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x15\n\rsource_folder\x18\x02 \x01(\t\x12\x35\n\x0finput_file_type\x18\x03 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\"\x8a\x01\n\x17\x42\x61tchJobDestinationPath\x12\x1a\n\x12\x64\x65stination_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x02 \x01(\t\x12\x37\n\x10output_file_type\x18\x03 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\"\x94\x02\n\x18\x42\x61tchJobExecutionDetails\x12\x13\n\x0bjob_timeout\x18\x01 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\x02 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x05 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"S\n\x15StartBatchJobResponse\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\")\n\x15\x43\x61ncelBatchJobRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"B\n\x16\x43\x61ncelBatchJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\",\n\x18GetBatchJobStatusRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"\xac\x01\n\x19GetBatchJobStatusResponse\x12\x38\n\njob_status\x18\x01 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\x12\x16\n\x0e\x66inished_files\x18\x04 \x01(\x05\x12\x13\n\x0btotal_files\x18\x05 \x01(\x05\",\n\x18GetBatchJobReportRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"a\n\x19GetBatchJobReportResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\x12\x17\n\x0freport_messages\x18\x03 \x03(\t\"`\n\x1dUpdateBatchTasksStatusRequest\x12?\n\x11\x62\x61tch_task_events\x18\x01 \x03(\x0b\x32$.qwak.batchjob.BatchTaskEventMessage\"I\n\x1dUpdateBatchTaskStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"z\n\x19\x41\x64vancedDeploymentOptions\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x01 \x01(\t\x12\x17\n\x0fpurchase_option\x18\x02 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x03 \x01(\t\"\x85\x03\n\x16\x42\x61tchJobDeploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12J\n\x0cmemory_units\x18\x04 \x01(\x0e\x32\x30.qwak.batchjob.BatchJobDeploymentSize.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x05 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"/\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x1a\x02\x18\x01\"\x99\x01\n\x15\x42\x61tchJobExecutionSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12S\n\x15pod_compute_resources\x18\x02 \x01(\x0b\x32\x34.qwak.user_application.common.v0.PodComputeResources\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\"Q\n\x14ListBatchJobsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"K\n\x15ListBatchJobsResponse\x12\x32\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x1e.qwak.batchjob.BatchJobDetails\"\x81\x03\n\x0f\x42\x61tchJobDetails\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x38\n\njob_status\x18\x03 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\x12;\n\x08job_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSizeB\x02\x18\x01\x12\x46\n\x18\x62\x61tch_job_execution_size\x18\x08 \x01(\x0b\x32$.qwak.batchjob.BatchJobExecutionSize\x12\x16\n\x0e\x65nvironment_id\x18\t \x01(\t\"+\n\x19GetBatchJobDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"y\n\x1aGetBatchJobDetailsResponse\x12\x31\n\tbatch_job\x18\x01 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"\x84\x04\n\x0f\x42\x61tchJobMessage\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\njob_status\x18\x07 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x15\n\rtotal_records\x18\x08 \x01(\x05\x12\x37\n\x08job_size\x18\t \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12;\n\x0freport_messages\x18\n \x03(\x0b\x32\".qwak.batchjob.ExecutionReportLine\x12\x43\n\x16\x65xecution_file_details\x18\x0b \x01(\x0b\x32#.qwak.batchjob.ExecutionFileDetails\x12<\n\x0ftask_executions\x18\x0c \x03(\x0b\x32#.qwak.batchjob.TaskExecutionDetails\"M\n\x13\x45xecutionReportLine\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04line\x18\x02 \x01(\t\"\x95\x02\n\x14\x45xecutionFileDetails\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x13\n\x0bsource_path\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x35\n\x0finput_file_type\x18\x05 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x06 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x16\n\x0e\x66inished_files\x18\x07 \x01(\x05\x12\x13\n\x0btotal_files\x18\x08 \x01(\x05\"\xfd\x01\n\x14TaskExecutionDetails\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.qwak.batchjob.BatchTaskStatusMessage\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enum_of_records\x18\x05 \x01(\x05\x12\x14\n\x08\x66ilename\x18\x06 \x01(\tB\x02\x18\x01\x12\x11\n\tfilenames\x18\x07 \x03(\t\"d\n$GetBatchJobPreSignedUploadUrlRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x17\n\x0fnumber_of_files\x18\x02 \x01(\x05\x12\x11\n\tfile_type\x18\x03 \x01(\t\"\x98\x01\n%GetBatchJobPreSignedUploadUrlResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0c\n\x04urls\x18\x04 \x03(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\"8\n&GetBatchJobPreSignedDownloadUrlRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"a\n\'GetBatchJobPreSignedDownloadUrlResponse\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"3\n\x1fGetBatchJobUploadDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xb4\x01\n GetBatchJobUploadDetailsResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12W\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"3\n!GetBatchJobDownloadDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x9b\x01\n\"GetBatchJobDownloadDetailsResponse\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12W\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"\xd7\x01\n\x1aUpdateDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x46\n\x17\x64\x65\x66\x61ult_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\"\x1d\n\x1bUpdateDefaultParamsResponse\".\n\x1a\x44\x65leteDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\x1d\n\x1b\x44\x65leteDefaultParamsResponse\"S\n&UpdateTaskIngestedRecordsAmountRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x18\n\x10ingested_records\x18\x02 \x01(\x03\")\n\'UpdateTaskIngestedRecordsAmountResponse*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x8d\x02\n\x15\x42\x61tchJobStatusMessage\x12\x1e\n\x1aUNDEFINED_BATCH_JOB_STATUS\x10\x00\x12\x1e\n\x1a\x42\x41TCH_JOB_COMMITTED_STATUS\x10\x01\x12\x1c\n\x18\x42\x41TCH_JOB_PENDING_STATUS\x10\x02\x12\x1c\n\x18\x42\x41TCH_JOB_RUNNING_STATUS\x10\x03\x12\x1d\n\x19\x42\x41TCH_JOB_FINISHED_STATUS\x10\x04\x12\x1b\n\x17\x42\x41TCH_JOB_FAILED_STATUS\x10\x05\x12\x1e\n\x1a\x42\x41TCH_JOB_CANCELLED_STATUS\x10\x06\x12\x1c\n\x18\x42\x41TCH_JOB_TIMEOUT_STATUS\x10\x07*\x9c\x02\n\x16\x42\x61tchTaskStatusMessage\x12\x1f\n\x1bUNDEFINED_BATCH_TASK_STATUS\x10\x00\x12\x1f\n\x1b\x42\x41TCH_TASK_COMMITTED_STATUS\x10\x01\x12#\n\x1f\x42\x41TCH_TASK_PENDING_START_STATUS\x10\x02\x12\x1d\n\x19\x42\x41TCH_TASK_RUNNING_STATUS\x10\x03\x12\x1e\n\x1a\x42\x41TCH_TASK_FINISHED_STATUS\x10\x04\x12\x1c\n\x18\x42\x41TCH_TASK_FAILED_STATUS\x10\x05\x12\x1f\n\x1b\x42\x41TCH_TASK_CANCELLED_STATUS\x10\x06\x12\x1d\n\x19\x42\x41TCH_TASK_TIMEOUT_STATUS\x10\x07\x32\xb4\x0e\n\x19\x42\x61tchJobManagementService\x12Z\n\rStartBatchJob\x12#.qwak.batchjob.StartBatchJobRequest\x1a$.qwak.batchjob.StartBatchJobResponse\x12]\n\x0e\x43\x61ncelBatchJob\x12$.qwak.batchjob.CancelBatchJobRequest\x1a%.qwak.batchjob.CancelBatchJobResponse\x12]\n\x0eStartWarmupJob\x12$.qwak.batchjob.StartWarmupJobRequest\x1a%.qwak.batchjob.StartWarmupJobResponse\x12`\n\x0f\x43\x61ncelWarmupJob\x12%.qwak.batchjob.CancelWarmupJobRequest\x1a&.qwak.batchjob.CancelWarmupJobResponse\x12\x66\n\x11GetBatchJobStatus\x12\'.qwak.batchjob.GetBatchJobStatusRequest\x1a(.qwak.batchjob.GetBatchJobStatusResponse\x12\x66\n\x11GetBatchJobReport\x12\'.qwak.batchjob.GetBatchJobReportRequest\x1a(.qwak.batchjob.GetBatchJobReportResponse\x12t\n\x16UpdateBatchTasksStatus\x12,.qwak.batchjob.UpdateBatchTasksStatusRequest\x1a,.qwak.batchjob.UpdateBatchTaskStatusResponse\x12Z\n\rListBatchJobs\x12#.qwak.batchjob.ListBatchJobsRequest\x1a$.qwak.batchjob.ListBatchJobsResponse\x12i\n\x12GetBatchJobDetails\x12(.qwak.batchjob.GetBatchJobDetailsRequest\x1a).qwak.batchjob.GetBatchJobDetailsResponse\x12\x8a\x01\n\x1dGetBatchJobPreSignedUploadUrl\x12\x33.qwak.batchjob.GetBatchJobPreSignedUploadUrlRequest\x1a\x34.qwak.batchjob.GetBatchJobPreSignedUploadUrlResponse\x12\x90\x01\n\x1fGetBatchJobPreSignedDownloadUrl\x12\x35.qwak.batchjob.GetBatchJobPreSignedDownloadUrlRequest\x1a\x36.qwak.batchjob.GetBatchJobPreSignedDownloadUrlResponse\x12{\n\x18GetBatchJobUploadDetails\x12..qwak.batchjob.GetBatchJobUploadDetailsRequest\x1a/.qwak.batchjob.GetBatchJobUploadDetailsResponse\x12\x81\x01\n\x1aGetBatchJobDownloadDetails\x12\x30.qwak.batchjob.GetBatchJobDownloadDetailsRequest\x1a\x31.qwak.batchjob.GetBatchJobDownloadDetailsResponse\x12l\n\x13UpdateDefaultParams\x12).qwak.batchjob.UpdateDefaultParamsRequest\x1a*.qwak.batchjob.UpdateDefaultParamsResponse\x12l\n\x13\x44\x65leteDefaultParams\x12).qwak.batchjob.DeleteDefaultParamsRequest\x1a*.qwak.batchjob.DeleteDefaultParamsResponse\x12\x90\x01\n\x1fUpdateTaskIngestedRecordsAmount\x12\x35.qwak.batchjob.UpdateTaskIngestedRecordsAmountRequest\x1a\x36.qwak.batchjob.UpdateTaskIngestedRecordsAmountResponseB.\n\x19\x63om.qwak.ai.batch.job.apiP\x01Z\x0f./;inferencejobb\x06proto3')

_INPUTFILETYPE = DESCRIPTOR.enum_types_by_name['InputFileType']
InputFileType = enum_type_wrapper.EnumTypeWrapper(_INPUTFILETYPE)
_OUTPUTFILETYPE = DESCRIPTOR.enum_types_by_name['OutputFileType']
OutputFileType = enum_type_wrapper.EnumTypeWrapper(_OUTPUTFILETYPE)
_BATCHJOBSTATUSMESSAGE = DESCRIPTOR.enum_types_by_name['BatchJobStatusMessage']
BatchJobStatusMessage = enum_type_wrapper.EnumTypeWrapper(_BATCHJOBSTATUSMESSAGE)
_BATCHTASKSTATUSMESSAGE = DESCRIPTOR.enum_types_by_name['BatchTaskStatusMessage']
BatchTaskStatusMessage = enum_type_wrapper.EnumTypeWrapper(_BATCHTASKSTATUSMESSAGE)
UNDEFINED_INPUT_FILE_TYPE = 0
CSV_INPUT_FILE_TYPE = 1
FEATHER_INPUT_FILE_TYPE = 2
PARQUET_INPUT_FILE_TYPE = 3
UNDEFINED_OUTPUT_FILE_TYPE = 0
CSV_OUTPUT_FILE_TYPE = 1
FEATHER_OUTPUT_FILE_TYPE = 2
PARQUET_OUTPUT_FILE_TYPE = 3
UNDEFINED_BATCH_JOB_STATUS = 0
BATCH_JOB_COMMITTED_STATUS = 1
BATCH_JOB_PENDING_STATUS = 2
BATCH_JOB_RUNNING_STATUS = 3
BATCH_JOB_FINISHED_STATUS = 4
BATCH_JOB_FAILED_STATUS = 5
BATCH_JOB_CANCELLED_STATUS = 6
BATCH_JOB_TIMEOUT_STATUS = 7
UNDEFINED_BATCH_TASK_STATUS = 0
BATCH_TASK_COMMITTED_STATUS = 1
BATCH_TASK_PENDING_START_STATUS = 2
BATCH_TASK_RUNNING_STATUS = 3
BATCH_TASK_FINISHED_STATUS = 4
BATCH_TASK_FAILED_STATUS = 5
BATCH_TASK_CANCELLED_STATUS = 6
BATCH_TASK_TIMEOUT_STATUS = 7


_STARTWARMUPJOBREQUEST = DESCRIPTOR.message_types_by_name['StartWarmupJobRequest']
_STARTWARMUPJOBRESPONSE = DESCRIPTOR.message_types_by_name['StartWarmupJobResponse']
_CANCELWARMUPJOBREQUEST = DESCRIPTOR.message_types_by_name['CancelWarmupJobRequest']
_CANCELWARMUPJOBRESPONSE = DESCRIPTOR.message_types_by_name['CancelWarmupJobResponse']
_STARTBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['StartBatchJobRequest']
_BATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['BatchJobRequest']
_BATCHJOBMODELDETAILS = DESCRIPTOR.message_types_by_name['BatchJobModelDetails']
_BATCHJOBDATADETAILS = DESCRIPTOR.message_types_by_name['BatchJobDataDetails']
_BATCHJOBSOURCEPATH = DESCRIPTOR.message_types_by_name['BatchJobSourcePath']
_BATCHJOBDESTINATIONPATH = DESCRIPTOR.message_types_by_name['BatchJobDestinationPath']
_BATCHJOBEXECUTIONDETAILS = DESCRIPTOR.message_types_by_name['BatchJobExecutionDetails']
_BATCHJOBPARAMETER = DESCRIPTOR.message_types_by_name['BatchJobParameter']
_STARTBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['StartBatchJobResponse']
_CANCELBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['CancelBatchJobRequest']
_CANCELBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['CancelBatchJobResponse']
_GETBATCHJOBSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobStatusRequest']
_GETBATCHJOBSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobStatusResponse']
_GETBATCHJOBREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobReportRequest']
_GETBATCHJOBREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobReportResponse']
_UPDATEBATCHTASKSSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateBatchTasksStatusRequest']
_UPDATEBATCHTASKSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateBatchTaskStatusResponse']
_ADVANCEDDEPLOYMENTOPTIONS = DESCRIPTOR.message_types_by_name['AdvancedDeploymentOptions']
_BATCHJOBDEPLOYMENTSIZE = DESCRIPTOR.message_types_by_name['BatchJobDeploymentSize']
_BATCHJOBEXECUTIONSIZE = DESCRIPTOR.message_types_by_name['BatchJobExecutionSize']
_LISTBATCHJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListBatchJobsRequest']
_LISTBATCHJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListBatchJobsResponse']
_BATCHJOBDETAILS = DESCRIPTOR.message_types_by_name['BatchJobDetails']
_GETBATCHJOBDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobDetailsRequest']
_GETBATCHJOBDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobDetailsResponse']
_BATCHJOBMESSAGE = DESCRIPTOR.message_types_by_name['BatchJobMessage']
_EXECUTIONREPORTLINE = DESCRIPTOR.message_types_by_name['ExecutionReportLine']
_EXECUTIONFILEDETAILS = DESCRIPTOR.message_types_by_name['ExecutionFileDetails']
_TASKEXECUTIONDETAILS = DESCRIPTOR.message_types_by_name['TaskExecutionDetails']
_GETBATCHJOBPRESIGNEDUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobPreSignedUploadUrlRequest']
_GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobPreSignedUploadUrlResponse']
_GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobPreSignedDownloadUrlRequest']
_GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobPreSignedDownloadUrlResponse']
_GETBATCHJOBUPLOADDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobUploadDetailsRequest']
_GETBATCHJOBUPLOADDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobUploadDetailsResponse']
_GETBATCHJOBDOWNLOADDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobDownloadDetailsRequest']
_GETBATCHJOBDOWNLOADDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobDownloadDetailsResponse']
_UPDATEDEFAULTPARAMSREQUEST = DESCRIPTOR.message_types_by_name['UpdateDefaultParamsRequest']
_UPDATEDEFAULTPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDefaultParamsResponse']
_DELETEDEFAULTPARAMSREQUEST = DESCRIPTOR.message_types_by_name['DeleteDefaultParamsRequest']
_DELETEDEFAULTPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDefaultParamsResponse']
_UPDATETASKINGESTEDRECORDSAMOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateTaskIngestedRecordsAmountRequest']
_UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateTaskIngestedRecordsAmountResponse']
_BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT = _BATCHJOBDEPLOYMENTSIZE.enum_types_by_name['MemoryUnit']
StartWarmupJobRequest = _reflection.GeneratedProtocolMessageType('StartWarmupJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTWARMUPJOBREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.StartWarmupJobRequest)
  })
_sym_db.RegisterMessage(StartWarmupJobRequest)

StartWarmupJobResponse = _reflection.GeneratedProtocolMessageType('StartWarmupJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTWARMUPJOBRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.StartWarmupJobResponse)
  })
_sym_db.RegisterMessage(StartWarmupJobResponse)

CancelWarmupJobRequest = _reflection.GeneratedProtocolMessageType('CancelWarmupJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELWARMUPJOBREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.CancelWarmupJobRequest)
  })
_sym_db.RegisterMessage(CancelWarmupJobRequest)

CancelWarmupJobResponse = _reflection.GeneratedProtocolMessageType('CancelWarmupJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELWARMUPJOBRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.CancelWarmupJobResponse)
  })
_sym_db.RegisterMessage(CancelWarmupJobResponse)

StartBatchJobRequest = _reflection.GeneratedProtocolMessageType('StartBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTBATCHJOBREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.StartBatchJobRequest)
  })
_sym_db.RegisterMessage(StartBatchJobRequest)

BatchJobRequest = _reflection.GeneratedProtocolMessageType('BatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobRequest)
  })
_sym_db.RegisterMessage(BatchJobRequest)

BatchJobModelDetails = _reflection.GeneratedProtocolMessageType('BatchJobModelDetails', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBMODELDETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobModelDetails)
  })
_sym_db.RegisterMessage(BatchJobModelDetails)

BatchJobDataDetails = _reflection.GeneratedProtocolMessageType('BatchJobDataDetails', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBDATADETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobDataDetails)
  })
_sym_db.RegisterMessage(BatchJobDataDetails)

BatchJobSourcePath = _reflection.GeneratedProtocolMessageType('BatchJobSourcePath', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBSOURCEPATH,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobSourcePath)
  })
_sym_db.RegisterMessage(BatchJobSourcePath)

BatchJobDestinationPath = _reflection.GeneratedProtocolMessageType('BatchJobDestinationPath', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBDESTINATIONPATH,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobDestinationPath)
  })
_sym_db.RegisterMessage(BatchJobDestinationPath)

BatchJobExecutionDetails = _reflection.GeneratedProtocolMessageType('BatchJobExecutionDetails', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBEXECUTIONDETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobExecutionDetails)
  })
_sym_db.RegisterMessage(BatchJobExecutionDetails)

BatchJobParameter = _reflection.GeneratedProtocolMessageType('BatchJobParameter', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBPARAMETER,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobParameter)
  })
_sym_db.RegisterMessage(BatchJobParameter)

StartBatchJobResponse = _reflection.GeneratedProtocolMessageType('StartBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTBATCHJOBRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.StartBatchJobResponse)
  })
_sym_db.RegisterMessage(StartBatchJobResponse)

CancelBatchJobRequest = _reflection.GeneratedProtocolMessageType('CancelBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBATCHJOBREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.CancelBatchJobRequest)
  })
_sym_db.RegisterMessage(CancelBatchJobRequest)

CancelBatchJobResponse = _reflection.GeneratedProtocolMessageType('CancelBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELBATCHJOBRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.CancelBatchJobResponse)
  })
_sym_db.RegisterMessage(CancelBatchJobResponse)

GetBatchJobStatusRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBSTATUSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobStatusRequest)
  })
_sym_db.RegisterMessage(GetBatchJobStatusRequest)

GetBatchJobStatusResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBSTATUSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobStatusResponse)
  })
_sym_db.RegisterMessage(GetBatchJobStatusResponse)

GetBatchJobReportRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREPORTREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobReportRequest)
  })
_sym_db.RegisterMessage(GetBatchJobReportRequest)

GetBatchJobReportResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREPORTRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobReportResponse)
  })
_sym_db.RegisterMessage(GetBatchJobReportResponse)

UpdateBatchTasksStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateBatchTasksStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHTASKSSTATUSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateBatchTasksStatusRequest)
  })
_sym_db.RegisterMessage(UpdateBatchTasksStatusRequest)

UpdateBatchTaskStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateBatchTaskStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHTASKSTATUSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateBatchTaskStatusResponse)
  })
_sym_db.RegisterMessage(UpdateBatchTaskStatusResponse)

AdvancedDeploymentOptions = _reflection.GeneratedProtocolMessageType('AdvancedDeploymentOptions', (_message.Message,), {
  'DESCRIPTOR' : _ADVANCEDDEPLOYMENTOPTIONS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.AdvancedDeploymentOptions)
  })
_sym_db.RegisterMessage(AdvancedDeploymentOptions)

BatchJobDeploymentSize = _reflection.GeneratedProtocolMessageType('BatchJobDeploymentSize', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBDEPLOYMENTSIZE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobDeploymentSize)
  })
_sym_db.RegisterMessage(BatchJobDeploymentSize)

BatchJobExecutionSize = _reflection.GeneratedProtocolMessageType('BatchJobExecutionSize', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBEXECUTIONSIZE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobExecutionSize)
  })
_sym_db.RegisterMessage(BatchJobExecutionSize)

ListBatchJobsRequest = _reflection.GeneratedProtocolMessageType('ListBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.ListBatchJobsRequest)
  })
_sym_db.RegisterMessage(ListBatchJobsRequest)

ListBatchJobsResponse = _reflection.GeneratedProtocolMessageType('ListBatchJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.ListBatchJobsResponse)
  })
_sym_db.RegisterMessage(ListBatchJobsResponse)

BatchJobDetails = _reflection.GeneratedProtocolMessageType('BatchJobDetails', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBDETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobDetails)
  })
_sym_db.RegisterMessage(BatchJobDetails)

GetBatchJobDetailsRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBDETAILSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobDetailsRequest)
  })
_sym_db.RegisterMessage(GetBatchJobDetailsRequest)

GetBatchJobDetailsResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBDETAILSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobDetailsResponse)
  })
_sym_db.RegisterMessage(GetBatchJobDetailsResponse)

BatchJobMessage = _reflection.GeneratedProtocolMessageType('BatchJobMessage', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBMESSAGE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobMessage)
  })
_sym_db.RegisterMessage(BatchJobMessage)

ExecutionReportLine = _reflection.GeneratedProtocolMessageType('ExecutionReportLine', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONREPORTLINE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.ExecutionReportLine)
  })
_sym_db.RegisterMessage(ExecutionReportLine)

ExecutionFileDetails = _reflection.GeneratedProtocolMessageType('ExecutionFileDetails', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONFILEDETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.ExecutionFileDetails)
  })
_sym_db.RegisterMessage(ExecutionFileDetails)

TaskExecutionDetails = _reflection.GeneratedProtocolMessageType('TaskExecutionDetails', (_message.Message,), {
  'DESCRIPTOR' : _TASKEXECUTIONDETAILS,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.TaskExecutionDetails)
  })
_sym_db.RegisterMessage(TaskExecutionDetails)

GetBatchJobPreSignedUploadUrlRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobPreSignedUploadUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBPRESIGNEDUPLOADURLREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobPreSignedUploadUrlRequest)
  })
_sym_db.RegisterMessage(GetBatchJobPreSignedUploadUrlRequest)

GetBatchJobPreSignedUploadUrlResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobPreSignedUploadUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobPreSignedUploadUrlResponse)
  })
_sym_db.RegisterMessage(GetBatchJobPreSignedUploadUrlResponse)

GetBatchJobPreSignedDownloadUrlRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobPreSignedDownloadUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobPreSignedDownloadUrlRequest)
  })
_sym_db.RegisterMessage(GetBatchJobPreSignedDownloadUrlRequest)

GetBatchJobPreSignedDownloadUrlResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobPreSignedDownloadUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobPreSignedDownloadUrlResponse)
  })
_sym_db.RegisterMessage(GetBatchJobPreSignedDownloadUrlResponse)

GetBatchJobUploadDetailsRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobUploadDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBUPLOADDETAILSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobUploadDetailsRequest)
  })
_sym_db.RegisterMessage(GetBatchJobUploadDetailsRequest)

GetBatchJobUploadDetailsResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobUploadDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBUPLOADDETAILSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobUploadDetailsResponse)
  })
_sym_db.RegisterMessage(GetBatchJobUploadDetailsResponse)

GetBatchJobDownloadDetailsRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobDownloadDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBDOWNLOADDETAILSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobDownloadDetailsRequest)
  })
_sym_db.RegisterMessage(GetBatchJobDownloadDetailsRequest)

GetBatchJobDownloadDetailsResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobDownloadDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBDOWNLOADDETAILSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.GetBatchJobDownloadDetailsResponse)
  })
_sym_db.RegisterMessage(GetBatchJobDownloadDetailsResponse)

UpdateDefaultParamsRequest = _reflection.GeneratedProtocolMessageType('UpdateDefaultParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDEFAULTPARAMSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateDefaultParamsRequest)
  })
_sym_db.RegisterMessage(UpdateDefaultParamsRequest)

UpdateDefaultParamsResponse = _reflection.GeneratedProtocolMessageType('UpdateDefaultParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDEFAULTPARAMSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateDefaultParamsResponse)
  })
_sym_db.RegisterMessage(UpdateDefaultParamsResponse)

DeleteDefaultParamsRequest = _reflection.GeneratedProtocolMessageType('DeleteDefaultParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDEFAULTPARAMSREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.DeleteDefaultParamsRequest)
  })
_sym_db.RegisterMessage(DeleteDefaultParamsRequest)

DeleteDefaultParamsResponse = _reflection.GeneratedProtocolMessageType('DeleteDefaultParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDEFAULTPARAMSRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.DeleteDefaultParamsResponse)
  })
_sym_db.RegisterMessage(DeleteDefaultParamsResponse)

UpdateTaskIngestedRecordsAmountRequest = _reflection.GeneratedProtocolMessageType('UpdateTaskIngestedRecordsAmountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETASKINGESTEDRECORDSAMOUNTREQUEST,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateTaskIngestedRecordsAmountRequest)
  })
_sym_db.RegisterMessage(UpdateTaskIngestedRecordsAmountRequest)

UpdateTaskIngestedRecordsAmountResponse = _reflection.GeneratedProtocolMessageType('UpdateTaskIngestedRecordsAmountResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE,
  '__module__' : 'qwak.batch_job.v1.batch_job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.UpdateTaskIngestedRecordsAmountResponse)
  })
_sym_db.RegisterMessage(UpdateTaskIngestedRecordsAmountResponse)

_BATCHJOBMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['BatchJobManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.batch.job.apiP\001Z\017./;inferencejob'
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._options = None
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDETAILS.fields_by_name['job_size']._options = None
  _BATCHJOBDETAILS.fields_by_name['job_size']._serialized_options = b'\030\001'
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._options = None
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._options = None
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._serialized_options = b'\030\001'
  _INPUTFILETYPE._serialized_start=6967
  _INPUTFILETYPE._serialized_end=7096
  _OUTPUTFILETYPE._serialized_start=7099
  _OUTPUTFILETYPE._serialized_end=7233
  _BATCHJOBSTATUSMESSAGE._serialized_start=7236
  _BATCHJOBSTATUSMESSAGE._serialized_end=7505
  _BATCHTASKSTATUSMESSAGE._serialized_start=7508
  _BATCHTASKSTATUSMESSAGE._serialized_end=7792
  _STARTWARMUPJOBREQUEST._serialized_start=246
  _STARTWARMUPJOBREQUEST._serialized_end=426
  _STARTWARMUPJOBRESPONSE._serialized_start=428
  _STARTWARMUPJOBRESPONSE._serialized_end=494
  _CANCELWARMUPJOBREQUEST._serialized_start=496
  _CANCELWARMUPJOBREQUEST._serialized_end=579
  _CANCELWARMUPJOBRESPONSE._serialized_start=581
  _CANCELWARMUPJOBRESPONSE._serialized_end=648
  _STARTBATCHJOBREQUEST._serialized_start=651
  _STARTBATCHJOBREQUEST._serialized_end=1300
  _BATCHJOBREQUEST._serialized_start=1303
  _BATCHJOBREQUEST._serialized_end=1506
  _BATCHJOBMODELDETAILS._serialized_start=1508
  _BATCHJOBMODELDETAILS._serialized_end=1566
  _BATCHJOBDATADETAILS._serialized_start=1569
  _BATCHJOBDATADETAILS._serialized_end=1798
  _BATCHJOBSOURCEPATH._serialized_start=1800
  _BATCHJOBSOURCEPATH._serialized_end=1921
  _BATCHJOBDESTINATIONPATH._serialized_start=1924
  _BATCHJOBDESTINATIONPATH._serialized_end=2062
  _BATCHJOBEXECUTIONDETAILS._serialized_start=2065
  _BATCHJOBEXECUTIONDETAILS._serialized_end=2341
  _BATCHJOBPARAMETER._serialized_start=2343
  _BATCHJOBPARAMETER._serialized_end=2390
  _STARTBATCHJOBRESPONSE._serialized_start=2392
  _STARTBATCHJOBRESPONSE._serialized_end=2475
  _CANCELBATCHJOBREQUEST._serialized_start=2477
  _CANCELBATCHJOBREQUEST._serialized_end=2518
  _CANCELBATCHJOBRESPONSE._serialized_start=2520
  _CANCELBATCHJOBRESPONSE._serialized_end=2586
  _GETBATCHJOBSTATUSREQUEST._serialized_start=2588
  _GETBATCHJOBSTATUSREQUEST._serialized_end=2632
  _GETBATCHJOBSTATUSRESPONSE._serialized_start=2635
  _GETBATCHJOBSTATUSRESPONSE._serialized_end=2807
  _GETBATCHJOBREPORTREQUEST._serialized_start=2809
  _GETBATCHJOBREPORTREQUEST._serialized_end=2853
  _GETBATCHJOBREPORTRESPONSE._serialized_start=2855
  _GETBATCHJOBREPORTRESPONSE._serialized_end=2952
  _UPDATEBATCHTASKSSTATUSREQUEST._serialized_start=2954
  _UPDATEBATCHTASKSSTATUSREQUEST._serialized_end=3050
  _UPDATEBATCHTASKSTATUSRESPONSE._serialized_start=3052
  _UPDATEBATCHTASKSTATUSRESPONSE._serialized_end=3125
  _ADVANCEDDEPLOYMENTOPTIONS._serialized_start=3127
  _ADVANCEDDEPLOYMENTOPTIONS._serialized_end=3249
  _BATCHJOBDEPLOYMENTSIZE._serialized_start=3252
  _BATCHJOBDEPLOYMENTSIZE._serialized_end=3641
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._serialized_start=3594
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._serialized_end=3641
  _BATCHJOBEXECUTIONSIZE._serialized_start=3644
  _BATCHJOBEXECUTIONSIZE._serialized_end=3797
  _LISTBATCHJOBSREQUEST._serialized_start=3799
  _LISTBATCHJOBSREQUEST._serialized_end=3880
  _LISTBATCHJOBSRESPONSE._serialized_start=3882
  _LISTBATCHJOBSRESPONSE._serialized_end=3957
  _BATCHJOBDETAILS._serialized_start=3960
  _BATCHJOBDETAILS._serialized_end=4345
  _GETBATCHJOBDETAILSREQUEST._serialized_start=4347
  _GETBATCHJOBDETAILSREQUEST._serialized_end=4390
  _GETBATCHJOBDETAILSRESPONSE._serialized_start=4392
  _GETBATCHJOBDETAILSRESPONSE._serialized_end=4513
  _BATCHJOBMESSAGE._serialized_start=4516
  _BATCHJOBMESSAGE._serialized_end=5032
  _EXECUTIONREPORTLINE._serialized_start=5034
  _EXECUTIONREPORTLINE._serialized_end=5111
  _EXECUTIONFILEDETAILS._serialized_start=5114
  _EXECUTIONFILEDETAILS._serialized_end=5391
  _TASKEXECUTIONDETAILS._serialized_start=5394
  _TASKEXECUTIONDETAILS._serialized_end=5647
  _GETBATCHJOBPRESIGNEDUPLOADURLREQUEST._serialized_start=5649
  _GETBATCHJOBPRESIGNEDUPLOADURLREQUEST._serialized_end=5749
  _GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE._serialized_start=5752
  _GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE._serialized_end=5904
  _GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST._serialized_start=5906
  _GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST._serialized_end=5962
  _GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE._serialized_start=5964
  _GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE._serialized_end=6061
  _GETBATCHJOBUPLOADDETAILSREQUEST._serialized_start=6063
  _GETBATCHJOBUPLOADDETAILSREQUEST._serialized_end=6114
  _GETBATCHJOBUPLOADDETAILSRESPONSE._serialized_start=6117
  _GETBATCHJOBUPLOADDETAILSRESPONSE._serialized_end=6297
  _GETBATCHJOBDOWNLOADDETAILSREQUEST._serialized_start=6299
  _GETBATCHJOBDOWNLOADDETAILSREQUEST._serialized_end=6350
  _GETBATCHJOBDOWNLOADDETAILSRESPONSE._serialized_start=6353
  _GETBATCHJOBDOWNLOADDETAILSRESPONSE._serialized_end=6508
  _UPDATEDEFAULTPARAMSREQUEST._serialized_start=6511
  _UPDATEDEFAULTPARAMSREQUEST._serialized_end=6726
  _UPDATEDEFAULTPARAMSRESPONSE._serialized_start=6728
  _UPDATEDEFAULTPARAMSRESPONSE._serialized_end=6757
  _DELETEDEFAULTPARAMSREQUEST._serialized_start=6759
  _DELETEDEFAULTPARAMSREQUEST._serialized_end=6805
  _DELETEDEFAULTPARAMSRESPONSE._serialized_start=6807
  _DELETEDEFAULTPARAMSRESPONSE._serialized_end=6836
  _UPDATETASKINGESTEDRECORDSAMOUNTREQUEST._serialized_start=6838
  _UPDATETASKINGESTEDRECORDSAMOUNTREQUEST._serialized_end=6921
  _UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE._serialized_start=6923
  _UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE._serialized_end=6964
  _BATCHJOBMANAGEMENTSERVICE._serialized_start=7795
  _BATCHJOBMANAGEMENTSERVICE._serialized_end=9639
# @@protoc_insertion_point(module_scope)
