# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/batch_job/v1/batch_job_events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/batch_job/v1/batch_job_events.proto\x12\rqwak.batchjob\x1a/qwak/user_application/common/v0/resources.proto\"\xa5\x01\n\x14\x42\x61tchJobEventMessage\x12\x45\n\x14\x62\x61tch_job_event_type\x18\x01 \x01(\x0e\x32\'.qwak.batchjob.BatchJobEventTypeMessage\x12\x14\n\x0c\x62\x61tch_job_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x04 \x01(\x05\x12\x10\n\x08\x66\x61ilures\x18\x05 \x01(\x05\"\x84\x02\n\x15\x42\x61tchTaskEventMessage\x12G\n\x15\x62\x61tch_task_event_type\x18\x01 \x01(\x0e\x32(.qwak.batchjob.BatchTaskEventTypeMessage\x12\x14\n\x0c\x62\x61tch_job_id\x18\x02 \x01(\t\x12\x15\n\rbatch_task_id\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x05 \x01(\x05\x12\x10\n\x08\x66\x61ilures\x18\x06 \x01(\x05\x12\x43\n\x19\x62\x61tch_task_failure_reason\x18\x07 \x01(\x0b\x32 .qwak.batchjob.TaskFailureReason\"\xec\x01\n\x12WarmupEventMessage\x12\x44\n\x15warmup_job_event_type\x18\x01 \x01(\x0e\x32%.qwak.batchjob.WarmupEventTypeMessage\x12\r\n\x05\x64\x65lay\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61ilures\x18\x03 \x01(\x05\x12.\n\x0bwarmup_size\x18\x04 \x01(\x0b\x32\x19.qwak.batchjob.WarmupSize\x12?\n\x10model_identifier\x18\x05 \x01(\x0b\x32%.qwak.batchjob.ModelIdentifierMessage\"\xb9\x02\n\nWarmupSize\x12\x0f\n\x03\x63pu\x18\x01 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x02 \x01(\x05\x42\x02\x18\x01\x12\x32\n\x0bmemory_unit\x18\x03 \x01(\x0e\x32\x19.qwak.batchjob.MemoryUnitB\x02\x18\x01\x12\x13\n\x0bnum_of_pods\x18\x04 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x05 \x01(\x05\x12H\n\rgpu_resources\x18\x06 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12S\n\x15pod_compute_resources\x18\x07 \x01(\x0b\x32\x34.qwak.user_application.common.v0.PodComputeResources\"\x90\x01\n\x16ModelIdentifierMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x12\n\naccount_id\x18\x06 \x01(\t\"\x80\x01\n\x11TaskFailureReason\x12\x46\n\x18task_failure_reason_code\x18\x01 \x01(\x0e\x32$.qwak.batchjob.TaskFailureReasonCode\x12#\n\x1btask_failure_reason_details\x18\x02 \x01(\t*\xf2\x01\n\x18\x42\x61tchJobEventTypeMessage\x12\x1d\n\x19UNDEFINED_BATCH_JOB_EVENT\x10\x00\x12\x17\n\x13\x42\x41TCH_JOB_COMMITTED\x10\x01\x12\x16\n\x12\x42\x41TCH_JOB_PREPARED\x10\x07\x12\x1b\n\x17\x42\x41TCH_JOB_TASKS_CREATED\x10\x02\x12\x17\n\x13\x42\x41TCH_JOB_CANCELLED\x10\x03\x12\x15\n\x11\x42\x41TCH_JOB_CLEANUP\x10\x04\x12\x1c\n\x18\x42\x41TCH_JOB_CHECK_FINISHED\x10\x05\x12\x1b\n\x17\x42\x41TCH_JOB_CHECK_TIMEOUT\x10\x06*\xce\x01\n\x19\x42\x61tchTaskEventTypeMessage\x12\x1e\n\x1aUNDEFINED_BATCH_TASK_EVENT\x10\x00\x12\x16\n\x12\x42\x41TCH_TASK_RUNNING\x10\x01\x12\x17\n\x13\x42\x41TCH_TASK_FINISHED\x10\x02\x12\x15\n\x11\x42\x41TCH_TASK_FAILED\x10\x03\x12\x1b\n\x17\x42\x41TCH_TASK_CHECK_STATUS\x10\x04\x12\x14\n\x10\x42\x41TCH_TASK_START\x10\x05\x12\x16\n\x12\x42\x41TCH_TASK_CLEANUP\x10\x06*e\n\x16WarmupEventTypeMessage\x12\x1e\n\x1aUNDEFINED_WARMUP_JOB_EVENT\x10\x00\x12\x18\n\x14WARMUP_JOB_COMMITTED\x10\x01\x12\x11\n\rWARMUP_CANCEL\x10\x02*+\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x9a\x05\n\x15TaskFailureReasonCode\x12\x35\n1TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED\x10\x00\x12\x44\n@TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE\x10\x01\x12\x43\n?TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE\x10\x02\x12\x37\n3TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE\x10\x03\x12@\n<TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE\x10\x04\x12?\n;TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE\x10\x05\x12\x34\n0TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE\x10\x06\x12\x46\nBTASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON\x10\x07\x12+\n\'TASK_FAILURE_REASON_CODE_UNKNOWN_REASON\x10\x08\x12X\nTTASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE\x10\tB.\n\x19\x63om.qwak.ai.batch.job.apiP\x01Z\x0f./;inferencejobb\x06proto3')

_BATCHJOBEVENTTYPEMESSAGE = DESCRIPTOR.enum_types_by_name['BatchJobEventTypeMessage']
BatchJobEventTypeMessage = enum_type_wrapper.EnumTypeWrapper(_BATCHJOBEVENTTYPEMESSAGE)
_BATCHTASKEVENTTYPEMESSAGE = DESCRIPTOR.enum_types_by_name['BatchTaskEventTypeMessage']
BatchTaskEventTypeMessage = enum_type_wrapper.EnumTypeWrapper(_BATCHTASKEVENTTYPEMESSAGE)
_WARMUPEVENTTYPEMESSAGE = DESCRIPTOR.enum_types_by_name['WarmupEventTypeMessage']
WarmupEventTypeMessage = enum_type_wrapper.EnumTypeWrapper(_WARMUPEVENTTYPEMESSAGE)
_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
_TASKFAILUREREASONCODE = DESCRIPTOR.enum_types_by_name['TaskFailureReasonCode']
TaskFailureReasonCode = enum_type_wrapper.EnumTypeWrapper(_TASKFAILUREREASONCODE)
UNDEFINED_BATCH_JOB_EVENT = 0
BATCH_JOB_COMMITTED = 1
BATCH_JOB_PREPARED = 7
BATCH_JOB_TASKS_CREATED = 2
BATCH_JOB_CANCELLED = 3
BATCH_JOB_CLEANUP = 4
BATCH_JOB_CHECK_FINISHED = 5
BATCH_JOB_CHECK_TIMEOUT = 6
UNDEFINED_BATCH_TASK_EVENT = 0
BATCH_TASK_RUNNING = 1
BATCH_TASK_FINISHED = 2
BATCH_TASK_FAILED = 3
BATCH_TASK_CHECK_STATUS = 4
BATCH_TASK_START = 5
BATCH_TASK_CLEANUP = 6
UNDEFINED_WARMUP_JOB_EVENT = 0
WARMUP_JOB_COMMITTED = 1
WARMUP_CANCEL = 2
UNKNOWN = 0
MIB = 1
GIB = 2
TASK_FAILURE_REASON_CODE_FAILURE_CODE_UNSPECIFIED = 0
TASK_FAILURE_REASON_CODE_NO_REPLICA_SETS_PODS_FOUND_FAILURE_CODE = 1
TASK_FAILURE_REASON_CODE_MODEL_CONTAINER_NOT_FOUND_FAILURE_CODE = 2
TASK_FAILURE_REASON_CODE_UNSCHEDULABLE_FAILURE_CODE = 3
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_NOT_FOUND_FAILURE_CODE = 4
TASK_FAILURE_REASON_CODE_MEMORY_LIMIT_EXCEEDED_FAILURE_CODE = 5
TASK_FAILURE_REASON_CODE_CRASH_LOOP_FAILURE_CODE = 6
TASK_FAILURE_REASON_CODE_CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON = 7
TASK_FAILURE_REASON_CODE_UNKNOWN_REASON = 8
TASK_FAILURE_REASON_CODE_DOCKER_IMAGE_GETS_THROTTLING_BY_CLOUD_PROVIDER_FAILURE_CODE = 9


_BATCHJOBEVENTMESSAGE = DESCRIPTOR.message_types_by_name['BatchJobEventMessage']
_BATCHTASKEVENTMESSAGE = DESCRIPTOR.message_types_by_name['BatchTaskEventMessage']
_WARMUPEVENTMESSAGE = DESCRIPTOR.message_types_by_name['WarmupEventMessage']
_WARMUPSIZE = DESCRIPTOR.message_types_by_name['WarmupSize']
_MODELIDENTIFIERMESSAGE = DESCRIPTOR.message_types_by_name['ModelIdentifierMessage']
_TASKFAILUREREASON = DESCRIPTOR.message_types_by_name['TaskFailureReason']
BatchJobEventMessage = _reflection.GeneratedProtocolMessageType('BatchJobEventMessage', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBEVENTMESSAGE,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchJobEventMessage)
  })
_sym_db.RegisterMessage(BatchJobEventMessage)

BatchTaskEventMessage = _reflection.GeneratedProtocolMessageType('BatchTaskEventMessage', (_message.Message,), {
  'DESCRIPTOR' : _BATCHTASKEVENTMESSAGE,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.BatchTaskEventMessage)
  })
_sym_db.RegisterMessage(BatchTaskEventMessage)

WarmupEventMessage = _reflection.GeneratedProtocolMessageType('WarmupEventMessage', (_message.Message,), {
  'DESCRIPTOR' : _WARMUPEVENTMESSAGE,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.WarmupEventMessage)
  })
_sym_db.RegisterMessage(WarmupEventMessage)

WarmupSize = _reflection.GeneratedProtocolMessageType('WarmupSize', (_message.Message,), {
  'DESCRIPTOR' : _WARMUPSIZE,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.WarmupSize)
  })
_sym_db.RegisterMessage(WarmupSize)

ModelIdentifierMessage = _reflection.GeneratedProtocolMessageType('ModelIdentifierMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODELIDENTIFIERMESSAGE,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.ModelIdentifierMessage)
  })
_sym_db.RegisterMessage(ModelIdentifierMessage)

TaskFailureReason = _reflection.GeneratedProtocolMessageType('TaskFailureReason', (_message.Message,), {
  'DESCRIPTOR' : _TASKFAILUREREASON,
  '__module__' : 'qwak.batch_job.v1.batch_job_events_pb2'
  # @@protoc_insertion_point(class_scope:qwak.batchjob.TaskFailureReason)
  })
_sym_db.RegisterMessage(TaskFailureReason)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.batch.job.apiP\001Z\017./;inferencejob'
  _WARMUPSIZE.fields_by_name['cpu']._options = None
  _WARMUPSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _WARMUPSIZE.fields_by_name['memory_amount']._options = None
  _WARMUPSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _WARMUPSIZE.fields_by_name['memory_unit']._options = None
  _WARMUPSIZE.fields_by_name['memory_unit']._serialized_options = b'\030\001'
  _WARMUPSIZE.fields_by_name['gpu_resources']._options = None
  _WARMUPSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _MODELIDENTIFIERMESSAGE.fields_by_name['branch_id']._options = None
  _MODELIDENTIFIERMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBEVENTTYPEMESSAGE._serialized_start=1373
  _BATCHJOBEVENTTYPEMESSAGE._serialized_end=1615
  _BATCHTASKEVENTTYPEMESSAGE._serialized_start=1618
  _BATCHTASKEVENTTYPEMESSAGE._serialized_end=1824
  _WARMUPEVENTTYPEMESSAGE._serialized_start=1826
  _WARMUPEVENTTYPEMESSAGE._serialized_end=1927
  _MEMORYUNIT._serialized_start=1929
  _MEMORYUNIT._serialized_end=1972
  _TASKFAILUREREASONCODE._serialized_start=1975
  _TASKFAILUREREASONCODE._serialized_end=2641
  _BATCHJOBEVENTMESSAGE._serialized_start=109
  _BATCHJOBEVENTMESSAGE._serialized_end=274
  _BATCHTASKEVENTMESSAGE._serialized_start=277
  _BATCHTASKEVENTMESSAGE._serialized_end=537
  _WARMUPEVENTMESSAGE._serialized_start=540
  _WARMUPEVENTMESSAGE._serialized_end=776
  _WARMUPSIZE._serialized_start=779
  _WARMUPSIZE._serialized_end=1092
  _MODELIDENTIFIERMESSAGE._serialized_start=1095
  _MODELIDENTIFIERMESSAGE._serialized_end=1239
  _TASKFAILUREREASON._serialized_start=1242
  _TASKFAILUREREASON._serialized_end=1370
# @@protoc_insertion_point(module_scope)
